BacktestDataConfigBuilder

Struct BacktestDataConfigBuilder 

pub struct BacktestDataConfigBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> BacktestDataConfigBuilder<S>

pub fn build(self) -> BacktestDataConfig
where S: IsComplete,

Finish building and return the requested object

pub fn data_type( self, value: NautilusDataType, ) -> BacktestDataConfigBuilder<SetDataType<S>>
where S::DataType: IsUnset,

Required.

The type of data to query from the catalog.

pub fn catalog_path( self, value: String, ) -> BacktestDataConfigBuilder<SetCatalogPath<S>>
where S::CatalogPath: IsUnset,

Required.

The path to the data catalog.

pub fn catalog_fs_protocol( self, value: String, ) -> BacktestDataConfigBuilder<SetCatalogFsProtocol<S>>
where S::CatalogFsProtocol: IsUnset,

Optional (Some / Option setters). The fsspec filesystem protocol for the catalog.

pub fn maybe_catalog_fs_protocol( self, value: Option<String>, ) -> BacktestDataConfigBuilder<SetCatalogFsProtocol<S>>
where S::CatalogFsProtocol: IsUnset,

Optional (Some / Option setters). The fsspec filesystem protocol for the catalog.

pub fn catalog_fs_storage_options( self, value: AHashMap<String, String>, ) -> BacktestDataConfigBuilder<SetCatalogFsStorageOptions<S>>
where S::CatalogFsStorageOptions: IsUnset,

Optional (Some / Option setters). The filesystem storage options for the catalog (e.g. cloud auth credentials).

pub fn maybe_catalog_fs_storage_options( self, value: Option<AHashMap<String, String>>, ) -> BacktestDataConfigBuilder<SetCatalogFsStorageOptions<S>>
where S::CatalogFsStorageOptions: IsUnset,

Optional (Some / Option setters). The filesystem storage options for the catalog (e.g. cloud auth credentials).

pub fn catalog_fs_rust_storage_options( self, value: AHashMap<String, String>, ) -> BacktestDataConfigBuilder<SetCatalogFsRustStorageOptions<S>>
where S::CatalogFsRustStorageOptions: IsUnset,

Optional (Some / Option setters). Rust-specific storage options for the catalog backend.

pub fn maybe_catalog_fs_rust_storage_options( self, value: Option<AHashMap<String, String>>, ) -> BacktestDataConfigBuilder<SetCatalogFsRustStorageOptions<S>>
where S::CatalogFsRustStorageOptions: IsUnset,

Optional (Some / Option setters). Rust-specific storage options for the catalog backend.

pub fn instrument_id( self, value: InstrumentId, ) -> BacktestDataConfigBuilder<SetInstrumentId<S>>
where S::InstrumentId: IsUnset,

Optional (Some / Option setters). The instrument ID for the data configuration (single).

pub fn maybe_instrument_id( self, value: Option<InstrumentId>, ) -> BacktestDataConfigBuilder<SetInstrumentId<S>>
where S::InstrumentId: IsUnset,

Optional (Some / Option setters). The instrument ID for the data configuration (single).

pub fn instrument_ids( self, value: Vec<InstrumentId>, ) -> BacktestDataConfigBuilder<SetInstrumentIds<S>>
where S::InstrumentIds: IsUnset,

Optional (Some / Option setters). Multiple instrument IDs for the data configuration.

pub fn maybe_instrument_ids( self, value: Option<Vec<InstrumentId>>, ) -> BacktestDataConfigBuilder<SetInstrumentIds<S>>
where S::InstrumentIds: IsUnset,

Optional (Some / Option setters). Multiple instrument IDs for the data configuration.

pub fn start_time( self, value: UnixNanos, ) -> BacktestDataConfigBuilder<SetStartTime<S>>
where S::StartTime: IsUnset,

Optional (Some / Option setters). The start time for the data configuration.

pub fn maybe_start_time( self, value: Option<UnixNanos>, ) -> BacktestDataConfigBuilder<SetStartTime<S>>
where S::StartTime: IsUnset,

Optional (Some / Option setters). The start time for the data configuration.

pub fn end_time( self, value: UnixNanos, ) -> BacktestDataConfigBuilder<SetEndTime<S>>
where S::EndTime: IsUnset,

Optional (Some / Option setters). The end time for the data configuration.

pub fn maybe_end_time( self, value: Option<UnixNanos>, ) -> BacktestDataConfigBuilder<SetEndTime<S>>
where S::EndTime: IsUnset,

Optional (Some / Option setters). The end time for the data configuration.

pub fn filter_expr( self, value: String, ) -> BacktestDataConfigBuilder<SetFilterExpr<S>>
where S::FilterExpr: IsUnset,

Optional (Some / Option setters). The additional filter expressions for the data catalog query.

pub fn maybe_filter_expr( self, value: Option<String>, ) -> BacktestDataConfigBuilder<SetFilterExpr<S>>
where S::FilterExpr: IsUnset,

Optional (Some / Option setters). The additional filter expressions for the data catalog query.

pub fn client_id( self, value: ClientId, ) -> BacktestDataConfigBuilder<SetClientId<S>>
where S::ClientId: IsUnset,

Optional (Some / Option setters). The client ID for the data configuration.

pub fn maybe_client_id( self, value: Option<ClientId>, ) -> BacktestDataConfigBuilder<SetClientId<S>>
where S::ClientId: IsUnset,

Optional (Some / Option setters). The client ID for the data configuration.

pub fn metadata( self, value: AHashMap<String, String>, ) -> BacktestDataConfigBuilder<SetMetadata<S>>
where S::Metadata: IsUnset,

Optional (Some / Option setters). The metadata for the data catalog query.

pub fn maybe_metadata( self, value: Option<AHashMap<String, String>>, ) -> BacktestDataConfigBuilder<SetMetadata<S>>
where S::Metadata: IsUnset,

Optional (Some / Option setters). The metadata for the data catalog query.

pub fn bar_spec( self, value: BarSpecification, ) -> BacktestDataConfigBuilder<SetBarSpec<S>>
where S::BarSpec: IsUnset,

Optional (Some / Option setters). The bar specification for the data catalog query.

pub fn maybe_bar_spec( self, value: Option<BarSpecification>, ) -> BacktestDataConfigBuilder<SetBarSpec<S>>
where S::BarSpec: IsUnset,

Optional (Some / Option setters). The bar specification for the data catalog query.

pub fn bar_types( self, value: Vec<String>, ) -> BacktestDataConfigBuilder<SetBarTypes<S>>
where S::BarTypes: IsUnset,

Optional (Some / Option setters). Explicit bar type strings for the data catalog query (e.g. “EUR/USD.SIM-1-MINUTE-LAST-EXTERNAL”).

pub fn maybe_bar_types( self, value: Option<Vec<String>>, ) -> BacktestDataConfigBuilder<SetBarTypes<S>>
where S::BarTypes: IsUnset,

Optional (Some / Option setters). Explicit bar type strings for the data catalog query (e.g. “EUR/USD.SIM-1-MINUTE-LAST-EXTERNAL”).

pub fn optimize_file_loading( self, value: bool, ) -> BacktestDataConfigBuilder<SetOptimizeFileLoading<S>>
where S::OptimizeFileLoading: IsUnset,

Optional (Some / Option setters). Default: false.

If directory-based file registration should be used for more efficient loading.

pub fn maybe_optimize_file_loading( self, value: Option<bool>, ) -> BacktestDataConfigBuilder<SetOptimizeFileLoading<S>>
where S::OptimizeFileLoading: IsUnset,

Optional (Some / Option setters). Default: false.

If directory-based file registration should be used for more efficient loading.