BacktestEngineConfigBuilder

Struct BacktestEngineConfigBuilder 

pub struct BacktestEngineConfigBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> BacktestEngineConfigBuilder<S>

pub fn build(self) -> BacktestEngineConfig
where S: IsComplete,

Finish building and return the requested object

pub fn environment( self, value: Environment, ) -> BacktestEngineConfigBuilder<SetEnvironment<S>>
where S::Environment: IsUnset,

Optional (Some / Option setters). Default: Environment::Backtest.

The kernel environment context.

pub fn maybe_environment( self, value: Option<Environment>, ) -> BacktestEngineConfigBuilder<SetEnvironment<S>>
where S::Environment: IsUnset,

Optional (Some / Option setters). Default: Environment::Backtest.

The kernel environment context.

pub fn trader_id( self, value: TraderId, ) -> BacktestEngineConfigBuilder<SetTraderId<S>>
where S::TraderId: IsUnset,

Optional (Some / Option setters). Default: <TraderId as Default>::default().

The trader ID for the node.

pub fn maybe_trader_id( self, value: Option<TraderId>, ) -> BacktestEngineConfigBuilder<SetTraderId<S>>
where S::TraderId: IsUnset,

Optional (Some / Option setters). Default: <TraderId as Default>::default().

The trader ID for the node.

pub fn load_state( self, value: bool, ) -> BacktestEngineConfigBuilder<SetLoadState<S>>
where S::LoadState: IsUnset,

Optional (Some / Option setters). Default: false.

If trading strategy state should be loaded from the database on start.

pub fn maybe_load_state( self, value: Option<bool>, ) -> BacktestEngineConfigBuilder<SetLoadState<S>>
where S::LoadState: IsUnset,

Optional (Some / Option setters). Default: false.

If trading strategy state should be loaded from the database on start.

pub fn save_state( self, value: bool, ) -> BacktestEngineConfigBuilder<SetSaveState<S>>
where S::SaveState: IsUnset,

Optional (Some / Option setters). Default: false.

If trading strategy state should be saved to the database on stop.

pub fn maybe_save_state( self, value: Option<bool>, ) -> BacktestEngineConfigBuilder<SetSaveState<S>>
where S::SaveState: IsUnset,

Optional (Some / Option setters). Default: false.

If trading strategy state should be saved to the database on stop.

pub fn logging( self, value: LoggerConfig, ) -> BacktestEngineConfigBuilder<SetLogging<S>>
where S::Logging: IsUnset,

Optional (Some / Option setters). Default: <LoggerConfig as Default>::default().

The logging configuration for the kernel.

pub fn maybe_logging( self, value: Option<LoggerConfig>, ) -> BacktestEngineConfigBuilder<SetLogging<S>>
where S::Logging: IsUnset,

Optional (Some / Option setters). Default: <LoggerConfig as Default>::default().

The logging configuration for the kernel.

pub fn instance_id( self, value: UUID4, ) -> BacktestEngineConfigBuilder<SetInstanceId<S>>
where S::InstanceId: IsUnset,

Optional (Some / Option setters). The unique instance identifier for the kernel.

pub fn maybe_instance_id( self, value: Option<UUID4>, ) -> BacktestEngineConfigBuilder<SetInstanceId<S>>
where S::InstanceId: IsUnset,

Optional (Some / Option setters). The unique instance identifier for the kernel.

pub fn timeout_connection( self, value: Duration, ) -> BacktestEngineConfigBuilder<SetTimeoutConnection<S>>
where S::TimeoutConnection: IsUnset,

Optional (Some / Option setters). Default: Duration::from_secs(60).

The timeout for all clients to connect and initialize.

pub fn maybe_timeout_connection( self, value: Option<Duration>, ) -> BacktestEngineConfigBuilder<SetTimeoutConnection<S>>
where S::TimeoutConnection: IsUnset,

Optional (Some / Option setters). Default: Duration::from_secs(60).

The timeout for all clients to connect and initialize.

pub fn timeout_reconciliation( self, value: Duration, ) -> BacktestEngineConfigBuilder<SetTimeoutReconciliation<S>>
where S::TimeoutReconciliation: IsUnset,

Optional (Some / Option setters). Default: Duration::from_secs(30).

The timeout for execution state to reconcile.

pub fn maybe_timeout_reconciliation( self, value: Option<Duration>, ) -> BacktestEngineConfigBuilder<SetTimeoutReconciliation<S>>
where S::TimeoutReconciliation: IsUnset,

Optional (Some / Option setters). Default: Duration::from_secs(30).

The timeout for execution state to reconcile.

pub fn timeout_portfolio( self, value: Duration, ) -> BacktestEngineConfigBuilder<SetTimeoutPortfolio<S>>
where S::TimeoutPortfolio: IsUnset,

Optional (Some / Option setters). Default: Duration::from_secs(10).

The timeout for portfolio to initialize margins and unrealized pnls.

pub fn maybe_timeout_portfolio( self, value: Option<Duration>, ) -> BacktestEngineConfigBuilder<SetTimeoutPortfolio<S>>
where S::TimeoutPortfolio: IsUnset,

Optional (Some / Option setters). Default: Duration::from_secs(10).

The timeout for portfolio to initialize margins and unrealized pnls.

pub fn timeout_disconnection( self, value: Duration, ) -> BacktestEngineConfigBuilder<SetTimeoutDisconnection<S>>
where S::TimeoutDisconnection: IsUnset,

Optional (Some / Option setters). Default: Duration::from_secs(10).

The timeout for all engine clients to disconnect.

pub fn maybe_timeout_disconnection( self, value: Option<Duration>, ) -> BacktestEngineConfigBuilder<SetTimeoutDisconnection<S>>
where S::TimeoutDisconnection: IsUnset,

Optional (Some / Option setters). Default: Duration::from_secs(10).

The timeout for all engine clients to disconnect.

pub fn delay_post_stop( self, value: Duration, ) -> BacktestEngineConfigBuilder<SetDelayPostStop<S>>
where S::DelayPostStop: IsUnset,

Optional (Some / Option setters). Default: Duration::from_secs(10).

The delay after stopping the node to await residual events before final shutdown.

pub fn maybe_delay_post_stop( self, value: Option<Duration>, ) -> BacktestEngineConfigBuilder<SetDelayPostStop<S>>
where S::DelayPostStop: IsUnset,

Optional (Some / Option setters). Default: Duration::from_secs(10).

The delay after stopping the node to await residual events before final shutdown.

pub fn timeout_shutdown( self, value: Duration, ) -> BacktestEngineConfigBuilder<SetTimeoutShutdown<S>>
where S::TimeoutShutdown: IsUnset,

Optional (Some / Option setters). Default: Duration::from_secs(5).

The timeout to await pending tasks cancellation during shutdown.

pub fn maybe_timeout_shutdown( self, value: Option<Duration>, ) -> BacktestEngineConfigBuilder<SetTimeoutShutdown<S>>
where S::TimeoutShutdown: IsUnset,

Optional (Some / Option setters). Default: Duration::from_secs(5).

The timeout to await pending tasks cancellation during shutdown.

pub fn cache( self, value: CacheConfig, ) -> BacktestEngineConfigBuilder<SetCache<S>>
where S::Cache: IsUnset,

Optional (Some / Option setters). The cache configuration.

crate::engine::BacktestEngine always overrides drop_instruments_on_reset to false on this config so that successive runs can reuse the same dataset.

pub fn maybe_cache( self, value: Option<CacheConfig>, ) -> BacktestEngineConfigBuilder<SetCache<S>>
where S::Cache: IsUnset,

Optional (Some / Option setters). The cache configuration.

crate::engine::BacktestEngine always overrides drop_instruments_on_reset to false on this config so that successive runs can reuse the same dataset.

pub fn msgbus( self, value: MessageBusConfig, ) -> BacktestEngineConfigBuilder<SetMsgbus<S>>
where S::Msgbus: IsUnset,

Optional (Some / Option setters). The message bus configuration.

pub fn maybe_msgbus( self, value: Option<MessageBusConfig>, ) -> BacktestEngineConfigBuilder<SetMsgbus<S>>
where S::Msgbus: IsUnset,

Optional (Some / Option setters). The message bus configuration.

pub fn data_engine( self, value: DataEngineConfig, ) -> BacktestEngineConfigBuilder<SetDataEngine<S>>
where S::DataEngine: IsUnset,

Optional (Some / Option setters). The data engine configuration.

pub fn maybe_data_engine( self, value: Option<DataEngineConfig>, ) -> BacktestEngineConfigBuilder<SetDataEngine<S>>
where S::DataEngine: IsUnset,

Optional (Some / Option setters). The data engine configuration.

pub fn risk_engine( self, value: RiskEngineConfig, ) -> BacktestEngineConfigBuilder<SetRiskEngine<S>>
where S::RiskEngine: IsUnset,

Optional (Some / Option setters). The risk engine configuration.

pub fn maybe_risk_engine( self, value: Option<RiskEngineConfig>, ) -> BacktestEngineConfigBuilder<SetRiskEngine<S>>
where S::RiskEngine: IsUnset,

Optional (Some / Option setters). The risk engine configuration.

pub fn exec_engine( self, value: ExecutionEngineConfig, ) -> BacktestEngineConfigBuilder<SetExecEngine<S>>
where S::ExecEngine: IsUnset,

Optional (Some / Option setters). The execution engine configuration.

pub fn maybe_exec_engine( self, value: Option<ExecutionEngineConfig>, ) -> BacktestEngineConfigBuilder<SetExecEngine<S>>
where S::ExecEngine: IsUnset,

Optional (Some / Option setters). The execution engine configuration.

pub fn portfolio( self, value: PortfolioConfig, ) -> BacktestEngineConfigBuilder<SetPortfolio<S>>
where S::Portfolio: IsUnset,

Optional (Some / Option setters). The portfolio configuration.

pub fn maybe_portfolio( self, value: Option<PortfolioConfig>, ) -> BacktestEngineConfigBuilder<SetPortfolio<S>>
where S::Portfolio: IsUnset,

Optional (Some / Option setters). The portfolio configuration.

pub fn streaming( self, value: StreamingConfig, ) -> BacktestEngineConfigBuilder<SetStreaming<S>>
where S::Streaming: IsUnset,

Optional (Some / Option setters). The configuration for streaming to feather files.

pub fn maybe_streaming( self, value: Option<StreamingConfig>, ) -> BacktestEngineConfigBuilder<SetStreaming<S>>
where S::Streaming: IsUnset,

Optional (Some / Option setters). The configuration for streaming to feather files.

pub fn bypass_logging( self, value: bool, ) -> BacktestEngineConfigBuilder<SetBypassLogging<S>>
where S::BypassLogging: IsUnset,

Optional (Some / Option setters). Default: false.

If logging should be bypassed.

pub fn maybe_bypass_logging( self, value: Option<bool>, ) -> BacktestEngineConfigBuilder<SetBypassLogging<S>>
where S::BypassLogging: IsUnset,

Optional (Some / Option setters). Default: false.

If logging should be bypassed.

pub fn run_analysis( self, value: bool, ) -> BacktestEngineConfigBuilder<SetRunAnalysis<S>>
where S::RunAnalysis: IsUnset,

Optional (Some / Option setters). Default: true.

If post backtest performance analysis should be run.

pub fn maybe_run_analysis( self, value: Option<bool>, ) -> BacktestEngineConfigBuilder<SetRunAnalysis<S>>
where S::RunAnalysis: IsUnset,

Optional (Some / Option setters). Default: true.

If post backtest performance analysis should be run.