pub struct BacktestRunConfig { /* private fields */ }Expand description
Represents the configuration for one specific backtest run. This includes a backtest engine with its actors and strategies, with the external inputs of venues and data.
Implementations
Sourceimpl BacktestRunConfig
impl BacktestRunConfig
Sourcepub fn builder() -> BacktestRunConfigBuilder
pub fn builder() -> BacktestRunConfigBuilder
Create an instance of BacktestRunConfig using the builder syntax
Sourceimpl BacktestRunConfig
impl BacktestRunConfig
pub fn id(&self) -> &str
pub fn venues(&self) -> &[BacktestVenueConfig]
pub fn data(&self) -> &[BacktestDataConfig]
pub fn engine(&self) -> &BacktestEngineConfig
pub fn chunk_size(&self) -> Option<usize>
pub fn raise_exception(&self) -> bool
pub fn dispose_on_completion(&self) -> bool
pub fn start(&self) -> Option<UnixNanos>
pub fn end(&self) -> Option<UnixNanos>