BacktestRunConfigBuilder

Struct BacktestRunConfigBuilder 

pub struct BacktestRunConfigBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> BacktestRunConfigBuilder<S>

pub fn build(self) -> BacktestRunConfig
where S: IsComplete,

Finish building and return the requested object

pub fn id(self, value: String) -> BacktestRunConfigBuilder<SetId<S>>
where S::Id: IsUnset,

Optional (Some / Option setters). Default: UUID4::new().to_string().

The unique identifier for this run configuration.

pub fn maybe_id( self, value: Option<String>, ) -> BacktestRunConfigBuilder<SetId<S>>
where S::Id: IsUnset,

Optional (Some / Option setters). Default: UUID4::new().to_string().

The unique identifier for this run configuration.

pub fn venues( self, value: Vec<BacktestVenueConfig>, ) -> BacktestRunConfigBuilder<SetVenues<S>>
where S::Venues: IsUnset,

Required.

The venue configurations for the backtest run.

pub fn data( self, value: Vec<BacktestDataConfig>, ) -> BacktestRunConfigBuilder<SetData<S>>
where S::Data: IsUnset,

Required.

The data configurations for the backtest run.

pub fn engine( self, value: BacktestEngineConfig, ) -> BacktestRunConfigBuilder<SetEngine<S>>
where S::Engine: IsUnset,

Optional (Some / Option setters). Default: <BacktestEngineConfig as Default>::default().

The backtest engine configuration (the core system kernel).

pub fn maybe_engine( self, value: Option<BacktestEngineConfig>, ) -> BacktestRunConfigBuilder<SetEngine<S>>
where S::Engine: IsUnset,

Optional (Some / Option setters). Default: <BacktestEngineConfig as Default>::default().

The backtest engine configuration (the core system kernel).

pub fn chunk_size( self, value: usize, ) -> BacktestRunConfigBuilder<SetChunkSize<S>>
where S::ChunkSize: IsUnset,

Optional (Some / Option setters). The number of data points to process in each chunk during streaming mode. If None, the backtest will run without streaming, loading all data at once.

pub fn maybe_chunk_size( self, value: Option<usize>, ) -> BacktestRunConfigBuilder<SetChunkSize<S>>
where S::ChunkSize: IsUnset,

Optional (Some / Option setters). The number of data points to process in each chunk during streaming mode. If None, the backtest will run without streaming, loading all data at once.

pub fn raise_exception( self, value: bool, ) -> BacktestRunConfigBuilder<SetRaiseException<S>>
where S::RaiseException: IsUnset,

Optional (Some / Option setters). Default: false.

If exceptions during build or run should interrupt processing.

pub fn maybe_raise_exception( self, value: Option<bool>, ) -> BacktestRunConfigBuilder<SetRaiseException<S>>
where S::RaiseException: IsUnset,

Optional (Some / Option setters). Default: false.

If exceptions during build or run should interrupt processing.

pub fn dispose_on_completion( self, value: bool, ) -> BacktestRunConfigBuilder<SetDisposeOnCompletion<S>>
where S::DisposeOnCompletion: IsUnset,

Optional (Some / Option setters). Default: true.

If the backtest engine should be disposed on completion of the run. If True, then will drop data and all state. If False, then will only drop data.

pub fn maybe_dispose_on_completion( self, value: Option<bool>, ) -> BacktestRunConfigBuilder<SetDisposeOnCompletion<S>>
where S::DisposeOnCompletion: IsUnset,

Optional (Some / Option setters). Default: true.

If the backtest engine should be disposed on completion of the run. If True, then will drop data and all state. If False, then will only drop data.

pub fn start(self, value: UnixNanos) -> BacktestRunConfigBuilder<SetStart<S>>
where S::Start: IsUnset,

Optional (Some / Option setters). The start datetime (UTC) for the backtest run. If None engine runs from the start of the data.

pub fn maybe_start( self, value: Option<UnixNanos>, ) -> BacktestRunConfigBuilder<SetStart<S>>
where S::Start: IsUnset,

Optional (Some / Option setters). The start datetime (UTC) for the backtest run. If None engine runs from the start of the data.

pub fn end(self, value: UnixNanos) -> BacktestRunConfigBuilder<SetEnd<S>>
where S::End: IsUnset,

Optional (Some / Option setters). The end datetime (UTC) for the backtest run. If None engine runs to the end of the data.

pub fn maybe_end( self, value: Option<UnixNanos>, ) -> BacktestRunConfigBuilder<SetEnd<S>>
where S::End: IsUnset,

Optional (Some / Option setters). The end datetime (UTC) for the backtest run. If None engine runs to the end of the data.