pub struct BacktestDataConfigBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> BacktestDataConfigBuilder<S>
impl<S: State> BacktestDataConfigBuilder<S>
Sourcepub fn build(self) -> BacktestDataConfigwhere
S: IsComplete,
pub fn build(self) -> BacktestDataConfigwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn data_type(
self,
value: NautilusDataType,
) -> BacktestDataConfigBuilder<SetDataType<S>>where
S::DataType: IsUnset,
pub fn data_type(
self,
value: NautilusDataType,
) -> BacktestDataConfigBuilder<SetDataType<S>>where
S::DataType: IsUnset,
Required.
The type of data to query from the catalog.
Sourcepub fn catalog_path(
self,
value: String,
) -> BacktestDataConfigBuilder<SetCatalogPath<S>>where
S::CatalogPath: IsUnset,
pub fn catalog_path(
self,
value: String,
) -> BacktestDataConfigBuilder<SetCatalogPath<S>>where
S::CatalogPath: IsUnset,
Required.
The path to the data catalog.
Sourcepub fn catalog_fs_protocol(
self,
value: String,
) -> BacktestDataConfigBuilder<SetCatalogFsProtocol<S>>where
S::CatalogFsProtocol: IsUnset,
pub fn catalog_fs_protocol(
self,
value: String,
) -> BacktestDataConfigBuilder<SetCatalogFsProtocol<S>>where
S::CatalogFsProtocol: IsUnset,
Sourcepub fn maybe_catalog_fs_protocol(
self,
value: Option<String>,
) -> BacktestDataConfigBuilder<SetCatalogFsProtocol<S>>where
S::CatalogFsProtocol: IsUnset,
pub fn maybe_catalog_fs_protocol(
self,
value: Option<String>,
) -> BacktestDataConfigBuilder<SetCatalogFsProtocol<S>>where
S::CatalogFsProtocol: IsUnset,
Sourcepub fn catalog_fs_storage_options(
self,
value: AHashMap<String, String>,
) -> BacktestDataConfigBuilder<SetCatalogFsStorageOptions<S>>where
S::CatalogFsStorageOptions: IsUnset,
pub fn catalog_fs_storage_options(
self,
value: AHashMap<String, String>,
) -> BacktestDataConfigBuilder<SetCatalogFsStorageOptions<S>>where
S::CatalogFsStorageOptions: IsUnset,
Sourcepub fn maybe_catalog_fs_storage_options(
self,
value: Option<AHashMap<String, String>>,
) -> BacktestDataConfigBuilder<SetCatalogFsStorageOptions<S>>where
S::CatalogFsStorageOptions: IsUnset,
pub fn maybe_catalog_fs_storage_options(
self,
value: Option<AHashMap<String, String>>,
) -> BacktestDataConfigBuilder<SetCatalogFsStorageOptions<S>>where
S::CatalogFsStorageOptions: IsUnset,
Sourcepub fn catalog_fs_rust_storage_options(
self,
value: AHashMap<String, String>,
) -> BacktestDataConfigBuilder<SetCatalogFsRustStorageOptions<S>>where
S::CatalogFsRustStorageOptions: IsUnset,
pub fn catalog_fs_rust_storage_options(
self,
value: AHashMap<String, String>,
) -> BacktestDataConfigBuilder<SetCatalogFsRustStorageOptions<S>>where
S::CatalogFsRustStorageOptions: IsUnset,
Sourcepub fn maybe_catalog_fs_rust_storage_options(
self,
value: Option<AHashMap<String, String>>,
) -> BacktestDataConfigBuilder<SetCatalogFsRustStorageOptions<S>>where
S::CatalogFsRustStorageOptions: IsUnset,
pub fn maybe_catalog_fs_rust_storage_options(
self,
value: Option<AHashMap<String, String>>,
) -> BacktestDataConfigBuilder<SetCatalogFsRustStorageOptions<S>>where
S::CatalogFsRustStorageOptions: IsUnset,
Sourcepub fn instrument_id(
self,
value: InstrumentId,
) -> BacktestDataConfigBuilder<SetInstrumentId<S>>where
S::InstrumentId: IsUnset,
pub fn instrument_id(
self,
value: InstrumentId,
) -> BacktestDataConfigBuilder<SetInstrumentId<S>>where
S::InstrumentId: IsUnset,
Sourcepub fn maybe_instrument_id(
self,
value: Option<InstrumentId>,
) -> BacktestDataConfigBuilder<SetInstrumentId<S>>where
S::InstrumentId: IsUnset,
pub fn maybe_instrument_id(
self,
value: Option<InstrumentId>,
) -> BacktestDataConfigBuilder<SetInstrumentId<S>>where
S::InstrumentId: IsUnset,
Sourcepub fn instrument_ids(
self,
value: Vec<InstrumentId>,
) -> BacktestDataConfigBuilder<SetInstrumentIds<S>>where
S::InstrumentIds: IsUnset,
pub fn instrument_ids(
self,
value: Vec<InstrumentId>,
) -> BacktestDataConfigBuilder<SetInstrumentIds<S>>where
S::InstrumentIds: IsUnset,
Sourcepub fn maybe_instrument_ids(
self,
value: Option<Vec<InstrumentId>>,
) -> BacktestDataConfigBuilder<SetInstrumentIds<S>>where
S::InstrumentIds: IsUnset,
pub fn maybe_instrument_ids(
self,
value: Option<Vec<InstrumentId>>,
) -> BacktestDataConfigBuilder<SetInstrumentIds<S>>where
S::InstrumentIds: IsUnset,
Sourcepub fn start_time(
self,
value: UnixNanos,
) -> BacktestDataConfigBuilder<SetStartTime<S>>where
S::StartTime: IsUnset,
pub fn start_time(
self,
value: UnixNanos,
) -> BacktestDataConfigBuilder<SetStartTime<S>>where
S::StartTime: IsUnset,
Sourcepub fn maybe_start_time(
self,
value: Option<UnixNanos>,
) -> BacktestDataConfigBuilder<SetStartTime<S>>where
S::StartTime: IsUnset,
pub fn maybe_start_time(
self,
value: Option<UnixNanos>,
) -> BacktestDataConfigBuilder<SetStartTime<S>>where
S::StartTime: IsUnset,
Sourcepub fn end_time(
self,
value: UnixNanos,
) -> BacktestDataConfigBuilder<SetEndTime<S>>where
S::EndTime: IsUnset,
pub fn end_time(
self,
value: UnixNanos,
) -> BacktestDataConfigBuilder<SetEndTime<S>>where
S::EndTime: IsUnset,
Sourcepub fn maybe_end_time(
self,
value: Option<UnixNanos>,
) -> BacktestDataConfigBuilder<SetEndTime<S>>where
S::EndTime: IsUnset,
pub fn maybe_end_time(
self,
value: Option<UnixNanos>,
) -> BacktestDataConfigBuilder<SetEndTime<S>>where
S::EndTime: IsUnset,
Sourcepub fn filter_expr(
self,
value: String,
) -> BacktestDataConfigBuilder<SetFilterExpr<S>>where
S::FilterExpr: IsUnset,
pub fn filter_expr(
self,
value: String,
) -> BacktestDataConfigBuilder<SetFilterExpr<S>>where
S::FilterExpr: IsUnset,
Sourcepub fn maybe_filter_expr(
self,
value: Option<String>,
) -> BacktestDataConfigBuilder<SetFilterExpr<S>>where
S::FilterExpr: IsUnset,
pub fn maybe_filter_expr(
self,
value: Option<String>,
) -> BacktestDataConfigBuilder<SetFilterExpr<S>>where
S::FilterExpr: IsUnset,
Sourcepub fn client_id(
self,
value: ClientId,
) -> BacktestDataConfigBuilder<SetClientId<S>>where
S::ClientId: IsUnset,
pub fn client_id(
self,
value: ClientId,
) -> BacktestDataConfigBuilder<SetClientId<S>>where
S::ClientId: IsUnset,
Sourcepub fn maybe_client_id(
self,
value: Option<ClientId>,
) -> BacktestDataConfigBuilder<SetClientId<S>>where
S::ClientId: IsUnset,
pub fn maybe_client_id(
self,
value: Option<ClientId>,
) -> BacktestDataConfigBuilder<SetClientId<S>>where
S::ClientId: IsUnset,
Sourcepub fn metadata(
self,
value: AHashMap<String, String>,
) -> BacktestDataConfigBuilder<SetMetadata<S>>where
S::Metadata: IsUnset,
pub fn metadata(
self,
value: AHashMap<String, String>,
) -> BacktestDataConfigBuilder<SetMetadata<S>>where
S::Metadata: IsUnset,
Sourcepub fn maybe_metadata(
self,
value: Option<AHashMap<String, String>>,
) -> BacktestDataConfigBuilder<SetMetadata<S>>where
S::Metadata: IsUnset,
pub fn maybe_metadata(
self,
value: Option<AHashMap<String, String>>,
) -> BacktestDataConfigBuilder<SetMetadata<S>>where
S::Metadata: IsUnset,
Sourcepub fn bar_spec(
self,
value: BarSpecification,
) -> BacktestDataConfigBuilder<SetBarSpec<S>>where
S::BarSpec: IsUnset,
pub fn bar_spec(
self,
value: BarSpecification,
) -> BacktestDataConfigBuilder<SetBarSpec<S>>where
S::BarSpec: IsUnset,
Sourcepub fn maybe_bar_spec(
self,
value: Option<BarSpecification>,
) -> BacktestDataConfigBuilder<SetBarSpec<S>>where
S::BarSpec: IsUnset,
pub fn maybe_bar_spec(
self,
value: Option<BarSpecification>,
) -> BacktestDataConfigBuilder<SetBarSpec<S>>where
S::BarSpec: IsUnset,
Sourcepub fn bar_types(
self,
value: Vec<String>,
) -> BacktestDataConfigBuilder<SetBarTypes<S>>where
S::BarTypes: IsUnset,
pub fn bar_types(
self,
value: Vec<String>,
) -> BacktestDataConfigBuilder<SetBarTypes<S>>where
S::BarTypes: IsUnset,
Sourcepub fn maybe_bar_types(
self,
value: Option<Vec<String>>,
) -> BacktestDataConfigBuilder<SetBarTypes<S>>where
S::BarTypes: IsUnset,
pub fn maybe_bar_types(
self,
value: Option<Vec<String>>,
) -> BacktestDataConfigBuilder<SetBarTypes<S>>where
S::BarTypes: IsUnset,
Sourcepub fn optimize_file_loading(
self,
value: bool,
) -> BacktestDataConfigBuilder<SetOptimizeFileLoading<S>>where
S::OptimizeFileLoading: IsUnset,
pub fn optimize_file_loading(
self,
value: bool,
) -> BacktestDataConfigBuilder<SetOptimizeFileLoading<S>>where
S::OptimizeFileLoading: IsUnset,
Sourcepub fn maybe_optimize_file_loading(
self,
value: Option<bool>,
) -> BacktestDataConfigBuilder<SetOptimizeFileLoading<S>>where
S::OptimizeFileLoading: IsUnset,
pub fn maybe_optimize_file_loading(
self,
value: Option<bool>,
) -> BacktestDataConfigBuilder<SetOptimizeFileLoading<S>>where
S::OptimizeFileLoading: IsUnset,